pub struct AllGuard { /* private fields */ }Expand description
A collection of guards that match if the conjunction of their check outcomes is true.
That is, all contained guard needs to match in order for the aggregate guard to match.
Construct an AllGuard using All.
Implementations